@@ -1,7 +1,7 @@
-.First.lib <- function(libname,pkgname,...) {
-if( is.null(getOption("robust"))) options(robust=FALSE)
-packageStartupMessage("Welcome to compositions, a package for compositional data analysis.\nFind an intro with \"? compositions\"\n")
-}
+#.First.lib <- function(libname,pkgname,...) {
+#if( is.null(getOption("robust"))) options(robust=FALSE)
+#packageStartupMessage("Welcome to compositions, a package for compositional data analysis.\nFind an intro with \"? compositions\"\n")
+#}
 
 .onAttach <- function(libname,pkgname,...) {
 if( is.null(getOption("robust"))) options(robust=FALSE)
